#ifndef NT2_INCLUDE_CONSTANTS__2OSQRTPI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS__2OSQRTPI_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/_2osqrtpi.hpp>

#endif
